"""
A plugin to include applications under development by the architecture team at edx .
"""

__version__ = '1.1.1'

default_app_config = 'edx_arch_experiments.apps.EdxArchExperimentsConfig'  # pylint: disable=invalid-name
